@@ -436,7 +436,7 @@ async def mikrotik_api_probe(host, mikrotik_api_cls, creds, **kwargs):
     """Try to connect to a Mikrotik host using a list of (username, password) credentials."""
     pend = [
         asyncio.create_task(x) for x in [
-            _mikrotik_probe(host, mikrotik_api_cls, creds, enable_ssl=x)
+            _mikrotik_probe(host, mikrotik_api_cls, creds, enable_ssl=x, **kwargs)
             for x in (True, False)
         ]
     ]
