@@ -10,7 +10,8 @@ from preseem.preseem_model import BaseModelObject
 from preseem import FakeNetworkMetadataModel, NetworkMetadataReference, FakePreseemModel
 from preseem.model_sync import sync_preseem_model, ElementSyncItem
 from preseem_protobuf.model.element_pb2 import ElementStatus
-from preseem_protobuf.model.account_pb2 import AccountType, AccountStatus
+from preseem_protobuf.model.account_pb2 import AccountStatus
+from preseem_protobuf.model.common_pb2 import AccountType
 from preseem.source_model import Attachment, Olt, Router, Service
 
 Account = namedtuple('Account', ('id', 'type', 'status', 'name', 'first_name', 'last_name'))
