@@ -41,11 +41,18 @@ class TestNetworkElementUpdate(unittest.TestCase):
         neu.pingable = True
         self.assertEqual(neu.pingable, True)
 
+        neu.errctx = network_element_update.ErrorContext()
         self.assertEqual(neu.ping_time, None)
         neu.ping_time = 120
         self.assertEqual(neu.ping_time, 120)
+        neu.ping_time = pow(2, 31)
+        self.assertEqual(neu.ping_time, 120)
+        neu.ping_time = -1
+        self.assertEqual(neu.ping_time, 120)
         neu.ping_time = None
         self.assertEqual(neu.ping_time, None)
+        self.assertEqual(len(neu.errctx.errors), 2)
+        neu.errctx = None
 
         neu.snmp_version = network_poller_pb2.SnmpVersion.V2C
         self.assertEqual(neu.snmp_version, network_poller_pb2.SnmpVersion.V2C)
@@ -57,6 +64,19 @@ class TestNetworkElementUpdate(unittest.TestCase):
         neu.sysobjid = None
         self.assertEqual(neu.sysobjid, None)
 
+        neu.errctx = network_element_update.ErrorContext()
+        self.assertEqual(neu.poll_time, None)
+        neu.poll_time = 60
+        self.assertEqual(neu.poll_time, 60)
+        neu.poll_time = pow(2, 31)
+        self.assertEqual(neu.poll_time, 60)
+        neu.poll_time = -1
+        self.assertEqual(neu.poll_time, 60)
+        neu.poll_time = None
+        self.assertEqual(neu.poll_time, None)
+        self.assertEqual(len(neu.errctx.errors), 2)
+        neu.errctx = None
+
         poller_version = '11.22.33'
         neu.poller_version = poller_version
         self.assertEqual(poller_version, neu.poller_version)
@@ -347,6 +367,12 @@ class TestNetworkElementUpdate(unittest.TestCase):
         ne.height = None
         self.assertEqual(ne.height, None)
 
+        self.assertEqual(ne.imsi, None)
+        ne.imsi = '123456789012345'
+        self.assertEqual(ne.imsi, '123456789012345')
+        ne.imsi = None
+        self.assertEqual(ne.imsi, None)
+
         # Interface
         intf = ne.interfaces.add()
         intf.id = '1'
@@ -947,6 +973,32 @@ class TestNetworkElementUpdate(unittest.TestCase):
         radio.wifi_mode = None
         self.assertEqual(radio.wifi_mode, None)
 
+        radio.errctx = network_element_update.ErrorContext()
+        self.assertEqual(radio.max_cpe_radios, None)
+        radio.max_cpe_radios = 10
+        self.assertEqual(radio.max_cpe_radios, 10)
+        radio.max_cpe_radios = -1
+        self.assertEqual(radio.max_cpe_radios, 10)
+        radio.max_cpe_radios = pow(2, 31)
+        self.assertEqual(radio.max_cpe_radios, 10)
+        radio.max_cpe_radios = None
+        self.assertEqual(radio.max_cpe_radios, None)
+        self.assertEqual(len(radio.errctx.errors), 2)
+        radio.errctx = None
+
+        radio.errctx = network_element_update.ErrorContext()
+        self.assertEqual(radio.max_distance, None)
+        radio.max_distance = 8000
+        self.assertEqual(radio.max_distance, 8000)
+        radio.max_distance = -1
+        self.assertEqual(radio.max_distance, 8000)
+        radio.max_distance = pow(2, 31)
+        self.assertEqual(radio.max_distance, 8000)
+        radio.max_distance = None
+        self.assertEqual(radio.max_distance, None)
+        self.assertEqual(len(radio.errctx.errors), 2)
+        radio.errctx = None
+
         # RadioStream
         stream = radio.streams.add()
         stream.id = '1'
